#!/bin/bash

VERSAO_JAVA="1.6"

function instalarPacote() {
    titulo=$1;

    echo -e "\n###################################################################################################";
    echo -e "\t${titulo}";
    echo -e "###################################################################################################\n";

    i=2;
    while [ ${i} -le $# ]; do # pegando os parametros de cada pacote

	eval biblioteca=\$$i;
	pacoteInstalado=`dpkg --get-selections | grep [^de]install | grep ${biblioteca} | awk '{print $1}'`; # verifica se o pacote esta instalado

	if [ -z $pacoteInstalado ]; then
		
            apt-get install ${biblioteca} -y --force-yes 1> /dev/null;

	    echo -e "\n---------------------------------------------------------------------------------------------------";
	    echo -e "O seguinte pacote ${biblioteca} foi instalado ao sistema";
            echo -e "---------------------------------------------------------------------------------------------------\n";

	else

	    echo -e "\n---------------------------------------------------------------------------------------------------";
            echo -e "O pacote ${biblioteca} já existe no sistema";
            echo -e "---------------------------------------------------------------------------------------------------\n";

        fi

	i=`expr ${i} + 1`

    done;
             
}


function instalarLink() {

    titulo=$1;
    origem=$2;
    destino=$3;
    nomeLink=$4;

    ls ${origem} >stdout-redirect 2> /dev/null

    if [ $? -eq 0 ]; then
        echo -e "\n###################################################################################################";
        echo -e "${titulo}";
        ln -s ${origem} ${destino}
        echo -e "O seguinte link ${nomeLink} foi criado na pasta ${destino} apontando para ${origem}";
        echo -e "###################################################################################################\n";
    else
	
	ls "${destino}/${nomeLink}" >stdout-redirect 2> /dev/null

	if [ $? -ne 0 ]; then
            echo -e "\n###################################################################################################";
	    echo -e "AVISO: Não foi encontrado nenhuma referência do arquivo \"${nomeLink}\" na pasta \"${destino}\". \nPor favor, procurar o arquivo e incluir na pasta \"${destino}\".\nA instalação será continuada.";
        echo -e "###################################################################################################\n";
	fi
    fi
    rm stdout-redirect	
}


function permissaoInstalarSmartcard() {
    echo -n "Tem certeza que gostaria de instalar a Applet no Sistema (s/n) ? ";
    read instalarSmartcard;

    case "$instalarSmartcard" in
	s) 
	    instalarSmartcard;
	    ;;

	n) 
	    echo "Instalação cancelada!"    
	    ;;
    esac

}

function permissaoDesinstalarSmartcard() {
    echo -n "Tem certeza que gostaria de desinstalar a Applet do Sistema (s/n) ? ";
    read desinstalarSmartcard;

    case "$desinstalarSmartcard" in
	s) 
	    desinstalarSmartcard;
	    ;;

	n) 
	    echo "Desinstalação cancelada!"    
	    ;;
    esac

}

function instalarLibJss4() {
    ./instalador_libjss4.sh instalar_sem_confirmacao
}

function desinstalarLibJss4() {
    ./instalador_libjss4.sh desinstalar_sem_confirmacao
}

function reiniciarServico() {
    titulo=$1;
    aplicativo=$2;

    echo -e "\n###################################################################################################";
    echo -e "${titulo}";
    echo -e "###################################################################################################\n";

   /etc/init.d/${aplicativo} restart
}

function instalarSmartcard() {
    clear;
    echo -e "Preparando para instalar os pacotes necessários para utlizar a leitora:";

    instalarPacote "Instalando o driver para leitura de USB" libusb-0.1-4;

    instalarPacote "Instalando o PCSC-lite para controlar a comunicação entre os SmartCards e as leitoras" pcscd libpcsclite1;

    instalarPacote "Instalando o programa pcsc-tools para verificar se o seu smartcard está funcionando" pcsc-tools;

    instalarPacote "Instalando o driver para a leitora (GemPC Twin)" libccid;

    instalarPacote "Instalando o OpenSC para permitir que os programas acessarem o dispositivo SmartCard" opensc libopensc2 libengine-pkcs11-openssl;

    instalarLink "Instalando um link simbólico para que os smartcard padrão PKCS11 possam ser utilizados pelo OpenSC" /usr/lib/pkcs11/opensc-pkcs11.so /usr/lib opensc-pkcs11.so;

    instalarPacote "Instalando os pacotes necessários para o Mozilla ou Firefox acessarem o dispositivo" iceape-browser mozilla-opensc;

    reiniciarServico "Reiniciando o aplicativo de controle do smartcard (pcscd)" pcscd

    instalarLibJss4;

    procedimentoFinalizarInstalacao "Procedimentos para completar a instalação";
}

function desinstalarSmartcard() {
    clear;

    echo -e "\n###################################################################################################";
    echo -e "Iniciando a Desinstalação";
    echo -e "###################################################################################################\n";

    unlink /usr/lib/opensc-pkcs11.so 2> /dev/null
    apt-get remove iceape-browser mozilla-opensc -y 1> /dev/null
    apt-get remove opensc libopensc2 libengine-pkcs11-openssl -y 1> /dev/null
    apt-get remove libccid -y 1> /dev/null
    apt-get remove pcsc-tools -y 1> /dev/null
    apt-get remove pcscd libpcsclite1 -y 1> /dev/null

    desinstalarLibJss4;

    echo -e "\n###################################################################################################";
    echo -e "\tA desinstalação foi completada";
    echo -e "###################################################################################################\n";
}

function procedimentoFinalizarInstalacao() {
    titulo=$1;

    echo -e "\n###################################################################################################";
    echo -e "${titulo}";
    echo -e "###################################################################################################\n";

    echo -e "1 - Executar o Firefox";
    echo -e "2 - Abrir o arquivo \"instalador_modulo.html\" que veio junto com o pacote de instalação deste instalador dentro do firefox."
    echo -e "3 - Ao abrir o arquivo confirme a instalação para que o navegador possa acessar a leitora."
    echo -e "4 - Após finalizar a instalação do módulo, feche o navegador para completar a instalação."

    echo -e "\nApós finalizar estes passos, seu computador poderá estar pronto para fazer o uso do leitor.";

    echo -e "\n\n** OBS: Caso a leitora esteja piscando a luz, reiniciar o serviço que comunica com a leitora.";
    echo -e "\nDigite o seguinte comando no console/terminal com permissão de root : \n\t/etc/init.d/pcscd restart.";

    echo -e "\n\n** OBS2: Caso precise ler estas informações novamente, execute: \n\t$0 ajuda ";
}

function verificaVersaoJava() {
	java -version 2>&1 | grep --regexp="$VERSAO_JAVA" &> /dev/null
	if [ $? -ne 0 ]; then
	   echo -e "\n###################################################################################################";
   	   echo -e "\tAVISO: Não foi encontrado a versão ${VERSAO_JAVA}.X do Java. \n\n\tPor favor, configurar o sistema para utilizar a versão 1.6 do java";
           echo -e "###################################################################################################\n";	
	   
           exit 1;
	fi
}

clear;
verificaVersaoJava;
if [ $UID -ne 0 ]; then

   echo -e "\n###################################################################################################";
   echo -e "\tAVISO: Este aplicativo deve ser executado com permissão de root";
   echo -e "###################################################################################################\n";

elif [ $# -ne 1 ]; then
    permissaoInstalarSmartcard;
elif [ $1 == "desinstalar" ]; then
    permissaoDesinstalarSmartcard;
elif [ $1 == "ajuda" ]; then
    procedimentoFinalizarInstalacao "Procedimentos para completar a instalação";
else
    echo -e "OPÇÃO DESCONHECIDA!\n\n* Parâmetros conhecidos:"
    echo -e "\n\t1- Sem Parâmetro para instalar as bibliotecas necessárias para o funcionamento do applet";
    echo -e "\n\t2- Paramêtro: \"desinstalar\" . Desinstala as bibliotecas.";

fi
echo -e "\n\n\n\n";

exit 0;
